@@ -37,4 +37,4 @@ class CustomAzureReader():
             :return: storage downloader object
         """
         byte_sequence = self.container_client.download_blob(file_name).readall()
-        return byte_sequence.decode("utf-8")
+        return json.loads(byte_sequence.decode("utf-8"))
