@@ -2,12 +2,14 @@
     CUSTOM READERS CLASSES
         - Class which manages reader tasks like auth, requests, pagination
 """
+import os
 from typing import Callable
 
 import httplib2
 from googleapiclient.discovery import build
 from oauth2client.service_account import ServiceAccountCredentials
 
+from sdc_dp_helpers.api_utilities.retry_managers import request_handler
 
 class BaseGAV4Reader:
     """
@@ -96,6 +98,11 @@ class BaseGAV4Reader:
         # Build the service object.
         return build(api_name, api_version, http=http)
 
+    @request_handler(
+        wait=int(os.environ.get('REQUEST_WAIT_TIME', 0)),
+        backoff_factor=float(os.environ.get('REQUEST_BACKOFF_FACTOR', 0.01)),
+        backoff_method=os.environ.get('REQUEST_BACKOFF_METHOD', 0.01)
+    )
     def get_report(
             self,
             queries: list,
